import pygame
from pygame.locals import *

class Entity(object):
    def __init__(self, pos, animation, level):
        self.dpos = Rect(0, 0, 0, 0)
        self.animation = animation
        self.level = level
        self.pos = Rect(pos, self.animation.size)
        self.on_ground = False
        
    def display(self, surface, camera, tick):
        self.animation.display(surface, (self.pos.x - camera.x, self.pos.y - camera.y), tick)

    def update(self):
        self.pos.x += self.dpos.x
        self.pos.y += self.dpos.y

        self.dpos.x = 0
        self.dpos.y = 0

    def ai(self):
        pass
        
    def check_collision(self, tilelayer):
        self.on_ground = False
        col_rect = Rect(self.pos.x, self.pos.y, self.pos.w, self.pos.h)
        if self.dpos.x > 0:
            col_rect.x += self.pos.w
            col_rect.w = self.dpos.x
            if tilelayer.collision(col_rect):
                self.dpos.x = 0
        elif self.dpos.x < 0:
            col_rect.x += self.dpos.x
            col_rect.w = -self.dpos.x
            if tilelayer.collision(col_rect):
                self.dpos.x = 0

        col_rect = Rect(self.pos.x, self.pos.y, self.pos.w, self.pos.h)
        if self.dpos.y > 0:
            col_rect.y += self.pos.h
            col_rect.h = self.dpos.y
            if tilelayer.collision(col_rect):
                self.dpos.y = 0
                self.on_ground = True
        elif self.dpos.y < 0:
            col_rect.y += self.dpos.y
            col_rect.h = -self.dpos.y
            if tilelayer.collision(col_rect):
                self.dpos.y = 0

    def is_touching(self, entity):
        return self.pos.colliderect(entity.pos)
                
    def move(self, dx, dy):
        self.dpos.x += dx
        self.dpos.y += dy
