#!/usr/bin/env python2

import pygame
from pygame.locals import *

import menu
import resources

class Engine(object):
    """Base engine for running the system."""
    contents = None
    color = (255, 255, 255)
    caption = "Terrorise the Village"
    background_color = (20,20,40)
    width, height = 640, 480
    updates_per_sec = 30
    
    def __init__(self, state_class):
        """Create an engine."""
        pygame.init()
        pygame.key.set_repeat(300, 50)
        if not pygame.font:
            exit()

        self.play_music = True
            
        self.s_font = pygame.font.Font("resources/Inconsolata.otf", 16)
        self.m_font = pygame.font.Font("resources/Inconsolata.otf", 32)
        self.l_font = pygame.font.Font("resources/Inconsolata.otf", 48)

        self.clock = pygame.time.Clock()
        
        self.pos = Rect(0, 0, self.width, self.height)
        self.screen = pygame.display.set_mode((self.width, self.height))

        pygame.display.set_caption(self.caption)

        resources.load_resources()
        
        self.state = state_class(self)

        self.background = pygame.Surface(self.screen.get_size())
        self.background = self.background.convert()
        self.background.fill(self.background_color)

        self.state.display(self.screen)
        
    def run(self):
        """Mainloop for catching events and performing updates."""
        while True:
            self.state.update()

            self.screen.blit(self.background, (0, 0))
            self.state.display(self.screen)

            pygame.display.flip()

            self.clock.tick(self.updates_per_sec)

            for event in pygame.event.get():
                if event.type == QUIT:
                    exit()
                else:
                    self.state.handle_event(event)

    def set_state(self, state):
        self.state = state
        
if __name__ == '__main__':
    Engine(menu.Menu).run()
