import pygame
from pygame.locals import *

import state
import game
import editor
import text
import sys

class Menu(state.State):
    """Main Menu gamestate."""
    def __init__(self, engine):
        super(Menu, self).__init__(engine)
        self.text = []
        title = text.Text(y=100, font=self.engine.l_font, text="Terrorise the Village", color=(120,0,30))
        title.center_x(0, self.engine.width)
        self.text.append(title)
        self.options = []
        self.select_color = (80,80,250)
        self.unselect_color = (30,30,200)

        y = 200
        options = [("NEW GAME", lambda: self.engine.set_state(game.Game(self.engine))),
                   ("EDITOR", lambda: self.engine.set_state(editor.Editor(self.engine))),
                   ("TOGGLE MUSIC", lambda: self.toggle_music()),
                   ("QUIT", sys.exit)]
        for label, callback in options:
            option = text.Text(y=y, font=self.engine.m_font, text=label, color=self.unselect_color)
            option.center_x(0, self.engine.width)
            y += 10 + option.get_rect().h
            self.text.append(option)
            self.options.append((option, callback))

        self.text.append(text.Text(x=0, y=420, font=self.engine.s_font, text="Collect all the villagers."))
        self.text.append(text.Text(x=0, y=440, font=self.engine.s_font, text="Pick them up and bring them to the lab."))
        self.text.append(text.Text(x=0, y=460, font=self.engine.s_font, text="Avoid robots, tanks and planes."))

        self.music_text = text.Text(x=0, y=0, font=self.engine.s_font, text="", color=(180,180,0))
        self.text.append(self.music_text)
        
        self.selection = 0
        self.select(0)
        
    def select(self, selection):
        self.options[self.selection][0].set_color(self.unselect_color)
        self.selection = selection
        self.options[self.selection][0].set_color(self.select_color)

    def select_up(self):
        self.select((self.selection - 1) % len(self.options))
    
    def select_down(self):
        self.select((self.selection + 1) % len(self.options))
        
    def update(self):
        if self.engine.play_music:
            self.music_text.set_text("MUSIC ON")
        else:
            self.music_text.set_text("MUSIC OFF")

    def toggle_music(self):
        self.engine.play_music = not self.engine.play_music
            
    def display(self, screen):
        for text in self.text:
            text.display(screen)

    def handle_event(self, event):
        if event.type == KEYDOWN:
            if event.key == K_UP:
                self.select_up()
            elif event.key == K_DOWN:
                self.select_down()
            elif event.key == K_RETURN:
                self.options[self.selection][1]()
            elif event.key == K_ESCAPE:
                sys.exit()
