import pygame
from pygame.locals import *

import tileset
import animation

# Load images into a dict so we can get them by name

image_list = {"tiles": "resources/tiles.png",
              "sprites": "resources/sprites.png",
              "house": "resources/house.png",
              "roof": "resources/roof.png",
              "butterfly": "resources/creature_butterfly.png",
              "cloud": "resources/cloud.png",
              "cloud2": "resources/cloud2.png",
              "crate": "resources/crate.png",
              "cavern": "resources/cavern_lab.png",
              "scientist": "resources/scientist.png",
              "robot1" : "resources/robot_1.png",
              "robot2" : "resources/robot_2.png",
              "tanks" : "resources/tanks.png",
              "man" : "resources/man.png",
              "tree" : "resources/tree.png",
              "plane" : "resources/plane.png",
              "sparks" : "resources/sparks.png"}
images = {}

tileset_list = {"foreground":
                    ([("empty", "tiles", (0, 0), False),
                      ("dirt", "tiles", (1, 0), True),
                      ("grass", "tiles", (2, 0), True),
                      ("l_grass", "tiles", (3, 0), True),
                      ("r_grass", "tiles", (4, 0), True),
                      ("rock", "tiles", (5, 0), True),
                      ("house_wall", "house", (1, 0), False),
                      ("house_door", "house", (1, 1), False),
                      ("house_window", "house", (0, 0), False),
                      ("house_window2", "house", (0, 1), False),
                      ("roof_l", "roof", (0, 0), True),
                      ("roof", "roof", (1, 0), True),
                      ("roof_r", "roof", (2, 0), True),
                      ("tl_rock", "tiles", (2, 1), True),
                      ("tr_rock", "tiles", (3, 1), True),
                      ("bl_rock", "tiles", (2, 2), True),
                      ("br_rock", "tiles", (3, 2), True),
                      ("cavern_m", "cavern", (0, 0), True),
                      ("cavern_l", "cavern", (1, 0), True),
                      ("cavern_d", "cavern", (2, 0), False)],
                     (32, 32)),
                "background":
                    ([("empty", "tiles", (0, 0), False),
                      ("b_rock", "tiles", (6, 0), False),
                      ("tl_b_rock", "tiles", (0, 1), False),
                      ("tr_b_rock", "tiles", (1, 1), False),
                      ("bl_b_rock", "tiles", (0, 2), False),
                      ("br_b_rock", "tiles", (1, 2), False)],
                     (32,32))}
tilesets = {}

animation_list = {"bird_l": ([("sprites", (3,0)),
                              ("sprites", (2,0))],
                             (32, 32), 4),
                  "bird_r": ([("sprites", (0,0)),
                              ("sprites", (1,0))],
                             (32, 32), 4),
                  "bird2_l": ([("sprites", (3,1)),
                               ("sprites", (2,1))],
                              (32, 32), 4),
                  "bird2_r": ([("sprites", (0,1)),
                              ("sprites", (1,1))],
                              (32, 32), 4),
                  "butterfly_r": ([("butterfly", (0,0)),
                                   ("butterfly", (1,0))],
                                  (32, 32), 6),
                  "butterfly_l": ([("butterfly", (0,1)),
                                   ("butterfly", (1,1))],
                                  (32, 32), 6),
                  "cloud": ([("cloud", (0,0))],
                            (256, 96), 1),
                  "cloud2": ([("cloud2", (0,0))],
                          (192, 96), 1),
                  "crate": ([("crate", (0,0))],
                            (32, 32), 1),
                  "robot1_l": ([("robot1", (0,0))],
                            (32, 32), 1),
                  "robot2_l": ([("robot2", (0,0))],
                            (32, 32), 1),
                  "robot1_r": ([("robot1", (1,0))],
                            (32, 32), 1),
                  "robot2_r": ([("robot2", (1,0))],
                            (32, 32), 1),
                  "scientist": ([("scientist", (0,0)),
                                 ("scientist", (1,0))],
                            (32, 32), 6),
                  "tree": ([("tree", (0,0))],
                            (64, 96), 4),
                  "plane": ([("plane", (0,0))],
                            (224, 128), 4),
                  "man_l": ([("man", (0,0)),
                             ("man", (1,0))],
                            (32, 32), 4),
                  "man_r": ([("man", (0,1)),
                             ("man", (1,1))],
                            (32, 32), 4),
                  "sparks": ([("sparks", (0,0)),
                              ("sparks", (0,0)),
                              ("sparks", (0,0)),
                              ("sparks", (0,1)),
                              ("sparks", (0,2)),
                              ("sparks", (0,3))],
                             (96, 64), 2),
                  "tank_up": ([("tanks", (0,1)),
                               ("tanks", (1,1)),
                               ("tanks", (2,1))],
                            (64, 32), 4),
                  "tank_down": ([("tanks", (0,0)),
                                 ("tanks", (1,0)),
                                 ("tanks", (2,0))],
                            (64, 32), 4)}
animations = {}

music_list = {"alarm": "resources/25031__sirplus__alarm-fatal.ogg",
              "loop1": "resources/28320__davepape__jchc-loop-013.ogg",
              "loop2": "resources/28324__davepape__dw-loop-035.ogg",
              "loop3": "resources/62405__fons__dist-perc-loop-1.ogg"}
music = {}

def load_resources():
    for name, filename in image_list.iteritems():
        images[name] = pygame.image.load(filename).convert_alpha()

    for name, (tile_list, tile_size) in tileset_list.iteritems():
        tilesets[name] = tileset.Tileset([(t_name, images[image_name], pos, is_blocked)
                                          for t_name, image_name, pos, is_blocked in tile_list], tile_size)

    for name, (frame_list, (w, h), speed) in animation_list.iteritems():
        animations[name] = animation.Animation(name, [(images[f_name], (x * w, y * h, w, h)) for f_name, (x, y) in frame_list], speed)

    for name, filename in music_list.iteritems():
        music[name] = filename
