import pygame
from pygame.locals import *

import random

class Tilelayer(object):
    def __init__(self, width, height, tileset, kind, camera_mult = 1):
        self.tileset = tileset
        self.width, self.height = width, height
        self.camera_mult = camera_mult
        if kind == "front":
            self.tiles = self.generate_front(width, height)
        else:
            self.tiles = self.generate_back(width, height)

    def get_total_size(self):
        return (self.width * self.tileset.tile_w, self.height * self.tileset.tile_h)
        
    def display(self, screen, camera):
        w, h = self.tileset.get_size()
        cx, cy = int(camera.x * self.camera_mult), int(camera.y * self.camera_mult)
        for i in xrange(max(0, cy / h), min((cy + camera.h) / h + 1, len(self.tiles))):
            for j in xrange(max(0, cx / w), min((cx + camera.w) / w + 1, len(self.tiles[i]))):
                self.tileset.display(screen, self.tiles[i][j],
                                     (j * w - camera.x * self.camera_mult, i * h - camera.y * self.camera_mult))

    def collision(self, rect):
        w, h = self.tileset.get_size()
        for tx in xrange((rect.x + 4)/ w, (rect.x + rect.w - 4) / w + 1):
            for ty in xrange((rect.y + 4) / h, (rect.y + rect.h - 2) / h + 1):
                if tx < 0 or ty < 0 or tx >= self.width or ty >= self.height or self.tileset.is_blocked(self.tiles[ty][tx]):
                    return True
        return False
    
    def set_tile(self, x, y, tile):
        self.tiles[y][x] = tile
    
    def generate_front(self, width, height):
        result = [[random.choice([1,1,1,1,5,5,5,5,5]) if y > 18 else
                   1 if y > 16 and (x < 40 or x > 60) else
                   1 if y > 14 and (x < 20 or x > 80) else
                   1 if y > 12 and (x < 10 or x > 90) else
                   1 if y > 10 and (x < 5 or x > 100) else
                   1 if y > 8 and (x > 110) else 0
                   for x in range(width)]
                  for y in range(height)]

        for _ in range(14):
            x = random.randint(20, 80)
            y = random.randint(8, 12)

            for w in range(random.randint(2, 5)):
                result[y][x + w] = 1

        for _ in range(5):
            x = random.randint(10, 90)
            y = random.randint(4, 8)

            for w in range(random.randint(2, 5)):
                result[y][x + w] = 1

                
        for x in range(width):
            for y in range(height):
                if result[y][x] == 1:
                    if y == 0 or result[y-1][x] == 0:
                        if x == 0 or result[y][x-1] == 0:
                            result[y][x] = 3
                        elif x == width - 1 or result[y][x+1] == 0:
                            result[y][x] = 4
                        else:
                            result[y][x] = 2
        return result

    def generate_back(self, width, height):
        result = [[0 for _ in range(width)]
                  for y in range(height)]

        for x in range(width / 2):
            start = random.randint(height / 8, height * 6 / 8)
            for y in range(start, height):
                result[y][x * 2] = 1
                result[y][x * 2 + 1] = 1

        for x in range(width):
            for y in range(height):
                if result[y][x] == 1:
                    top = y == 0 or result[y-1][x] != 0
                    left = x == 0 or result[y][x-1] != 0
                    right = x == (width - 1) or result[y][x+1] != 0
                    bottom = y == (height - 1) or result[y+1][x] != 0
                    if not top and not left:
                        result[y][x] = self.tileset.by_name("tl_b_rock")
                    elif not top and not right:
                        result[y][x] = self.tileset.by_name("tr_b_rock")
                    elif not bottom and not left:
                        result[y][x] = self.tileset.by_name("bl_b_rock")
                    elif not bottom and not right:
                        result[y][x] = self.tileset.by_name("br_b_rock")
                    else:
                        result[y][x] = self.tileset.by_name("b_rock")
                else:
                    result[y][x] = self.tileset.by_name("empty")
        return result
