import pygame
from pygame.locals import *

class Tileset(object):
    def __init__(self, tile_list, tile_size):
        """Creates a tileset using an array

        tile_size should be (width, height)

        Tiles in the tile_list should be:
        ("Name", image, (x, y), blocked)

        X & Y is specified using tile x & y
        (i.e. the first tile is (0, 0) second is (1, 0))
        """
        self.tile_size = tile_size
        self.tile_w, self.tile_h = tile_size
        self.tile_names = [name for name,_,_,_ in tile_list]
        self.tile_images = [image for _,image,_,_ in tile_list]
        self.tile_pos = [Rect(x * self.tile_w, y * self.tile_h, self.tile_w, self.tile_h) for _,_,(x,y),_ in tile_list]
        self.tile_blocked = [is_blocked for _,_,_,is_blocked in tile_list]

    def display(self, surface, tile_index, pos):
        surface.blit(self.tile_images[tile_index], pos, self.tile_pos[tile_index])

    def by_name(self, name):
        return self.tile_names.index(name)
        
    def is_blocked(self, tile_index):
        return self.tile_blocked[tile_index]
    
    def get_size(self):
        return self.tile_size
